# -*- coding: utf-8 -*-
# #!/usr/bin/env python
import os
import sys
from django.conf import settings

if __name__ == "__main__":
    os.environ.setdefault("DJANGO_SETTINGS_MODULE", "eeapp.settings")
    # os.environ.setdefault("DJANGO_SETTINGS_MODULE", settings)

    from django.core.management import execute_from_command_line

    execute_from_command_line(sys.argv)


# from seller.models_locations import Area
# from seller.models_seller import Shop,ShopAdmin
import django
if django.VERSION >= (1, 7):
    django.setup()
# s = Shop.objects.get(pk='4')
# print s


#!/usr/bin/env python

# import sys
# import os
#

# # print e
#
# a = float('12.0')
# print a



class ChinaLocCreater:
    def __init__(self, province, city, area):
        self.province = province
        self.city = city
        self.area = area

    def provinces(self):
        from eeapp.location.models import Province
        if Province.objects.all().count() < 1:
            f = open(self.province)
            for line in f:
                a, b = line.split('@@@@')
                Province.objects.create(
                    province_id=a.strip().lstrip(), province=b)
            f.close()

    def citys(self):
        from eeapp.location.models import City, Province
        if City.objects.all().count() < 1:
            f = open(self.city)
            for line in f:
                a, b, c = line.split('@@@@')
                try:
                    father = Province.objects.get(
                        province_id=c.strip().lstrip())
                    City.objects.create(
                        city_id=a.strip().lstrip(), city=b, father=father)
                except:
                    print(line)
            f.close()

    def areas(self):
        from eeapp.location.models import City, Area
        if Area.objects.all().count() < 1:
            f = open(self.area)
            for line in f:
                a, b, c = line.split('@@@@')
                try:
                    father = City.objects.get(city_id=c.strip().lstrip())
                    Area.objects.create(
                        area_id=a.strip().lstrip(), area=b, father=father)
                except:
                    print(line)
            f.close()

    def importData(self):
        self.provinces()
        self.citys()
        self.areas()


file_path = os.path.join(settings.BASE_DIR, 'location/static/location/chinese')
p = file_path + '/province.txt'
c = file_path + '/city.txt'
a = file_path + '/area.txt'

ChinaLocCreater(province=p, city=c, area=a).importData()



# -*- coding: UTF-8 -*-
from django.db import models
from django.core.files.images import ImageFile
from django.core.files.storage import FileSystemStorage
from django.conf import settings


class ImageStorage(FileSystemStorage):

    def __init__(self, location=settings.MEDIA_ROOT, base_url=settings.MEDIA_URL):
        # 初始化
        super(ImageStorage, self).__init__(location, base_url)

    # 重写 _save方法
    def _save(self, name, content):
        import os, time, random

        file = ImageFile(content)
        width = file.width
        height = file.height

        # 文件扩展名
        ext = os.path.splitext(name)[1]
        # 文件目录
        d = os.path.dirname(name)
        # 定义文件名，年月日时分秒随机数
        fn = time.strftime('%Y%m%d%H%M%S')
        fn = fn + '_%d' % random.randint(0, 100)
        fn = fn + "@%dX%d" %(width,height)
        # 重写合成文件名
        name = os.path.join(d, fn + ext)

        # 调用父类方法
        return super(ImageStorage, self)._save(name, content)

    def url(self, name):
        url = super(ImageStorage,self).url(name)
        host = settings.MEDIA_HOST or ''

        return host + url


class ImageField(models.ImageField):
    def __init__(self, verbose_name=None, name=None, width_field=None, height_field=None, **kwargs):
        self.width_field, self.height_field = width_field, height_field
        kwargs['storage'] = ImageStorage()
        super().__init__(verbose_name, name, **kwargs)